/* This is a generated file, don't edit */

#define NUM_APPLETS 227

const char applet_names[] ALIGN1 = ""
"[" "\0"
"[[" "\0"
"addgroup" "\0"
"adduser" "\0"
"adjtimex" "\0"
"ar" "\0"
"arp" "\0"
"arping" "\0"
"ash" "\0"
"awk" "\0"
"basename" "\0"
"bbconfig" "\0"
"bunzip2" "\0"
"bzcat" "\0"
"bzip2" "\0"
"cal" "\0"
"cat" "\0"
"chgrp" "\0"
"chmod" "\0"
"chown" "\0"
"chpasswd" "\0"
"chroot" "\0"
"chrt" "\0"
"chvt" "\0"
"cksum" "\0"
"clear" "\0"
"cmp" "\0"
"comm" "\0"
"cp" "\0"
"cpio" "\0"
"crond" "\0"
"crontab" "\0"
"cryptpw" "\0"
"cut" "\0"
"date" "\0"
"dc" "\0"
"dd" "\0"
"deallocvt" "\0"
"delgroup" "\0"
"deluser" "\0"
"df" "\0"
"dhcprelay" "\0"
"diff" "\0"
"dirname" "\0"
"dmesg" "\0"
"dnsd" "\0"
"dos2unix" "\0"
"du" "\0"
"dumpkmap" "\0"
"echo" "\0"
"ed" "\0"
"egrep" "\0"
"eject" "\0"
"env" "\0"
"ether-wake" "\0"
"expand" "\0"
"expr" "\0"
"fakeidentd" "\0"
"false" "\0"
"fbset" "\0"
"fdflush" "\0"
"fdformat" "\0"
"fdisk" "\0"
"fgrep" "\0"
"find" "\0"
"fold" "\0"
"free" "\0"
"freeramdisk" "\0"
"fsck" "\0"
"ftpget" "\0"
"ftpput" "\0"
"fuser" "\0"
"getopt" "\0"
"getty" "\0"
"grep" "\0"
"gunzip" "\0"
"gzip" "\0"
"halt" "\0"
"hdparm" "\0"
"head" "\0"
"hexdump" "\0"
"hostid" "\0"
"hostname" "\0"
"hwclock" "\0"
"id" "\0"
"ifconfig" "\0"
"ifdown" "\0"
"ifup" "\0"
"inetd" "\0"
"init" "\0"
"install" "\0"
"ipcalc" "\0"
"ipcrm" "\0"
"ipcs" "\0"
"kill" "\0"
"killall" "\0"
"killall5" "\0"
"klogd" "\0"
"last" "\0"
"length" "\0"
"less" "\0"
"linux32" "\0"
"linux64" "\0"
"linuxrc" "\0"
"ln" "\0"
"loadfont" "\0"
"loadkmap" "\0"
"logger" "\0"
"login" "\0"
"logname" "\0"
"logread" "\0"
"ls" "\0"
"md5sum" "\0"
"mesg" "\0"
"microcom" "\0"
"mkdir" "\0"
"mkfifo" "\0"
"mknod" "\0"
"mkswap" "\0"
"mktemp" "\0"
"more" "\0"
"mount" "\0"
"mountpoint" "\0"
"mv" "\0"
"nameif" "\0"
"nc" "\0"
"netstat" "\0"
"nice" "\0"
"nmeter" "\0"
"nohup" "\0"
"nslookup" "\0"
"od" "\0"
"openvt" "\0"
"passwd" "\0"
"patch" "\0"
"pidof" "\0"
"ping" "\0"
"ping6" "\0"
"pivot_root" "\0"
"pkill" "\0"
"poweroff" "\0"
"printenv" "\0"
"printf" "\0"
"ps" "\0"
"pscan" "\0"
"pwd" "\0"
"rdate" "\0"
"readlink" "\0"
"readprofile" "\0"
"realpath" "\0"
"reboot" "\0"
"renice" "\0"
"reset" "\0"
"resize" "\0"
"rm" "\0"
"rmdir" "\0"
"route" "\0"
"rpm" "\0"
"rpm2cpio" "\0"
"script" "\0"
"sed" "\0"
"seq" "\0"
"setarch" "\0"
"setconsole" "\0"
"setkeycodes" "\0"
"setsid" "\0"
"sh" "\0"
"sha1sum" "\0"
"sleep" "\0"
"sort" "\0"
"split" "\0"
"start-stop-daemon" "\0"
"stat" "\0"
"strings" "\0"
"stty" "\0"
"su" "\0"
"sulogin" "\0"
"sum" "\0"
"swapoff" "\0"
"swapon" "\0"
"switch_root" "\0"
"sync" "\0"
"sysctl" "\0"
"syslogd" "\0"
"tail" "\0"
"tar" "\0"
"tee" "\0"
"telnet" "\0"
"telnetd" "\0"
"test" "\0"
"tftp" "\0"
"tftpd" "\0"
"time" "\0"
"top" "\0"
"touch" "\0"
"tr" "\0"
"traceroute" "\0"
"true" "\0"
"tty" "\0"
"udhcpc" "\0"
"udhcpd" "\0"
"udpsvd" "\0"
"umount" "\0"
"uname" "\0"
"uncompress" "\0"
"unexpand" "\0"
"uniq" "\0"
"unix2dos" "\0"
"unzip" "\0"
"uptime" "\0"
"usleep" "\0"
"uudecode" "\0"
"uuencode" "\0"
"vconfig" "\0"
"vi" "\0"
"vlock" "\0"
"watch" "\0"
"watchdog" "\0"
"wc" "\0"
"wget" "\0"
"which" "\0"
"who" "\0"
"whoami" "\0"
"xargs" "\0"
"yes" "\0"
"zcat" "\0"
"zcip" "\0"
;

int (*const applet_main[])(int argc, char **argv) = {
test_main,
test_main,
addgroup_main,
adduser_main,
adjtimex_main,
ar_main,
arp_main,
arping_main,
ash_main,
awk_main,
basename_main,
bbconfig_main,
bunzip2_main,
bunzip2_main,
bzip2_main,
cal_main,
cat_main,
chgrp_main,
chmod_main,
chown_main,
chpasswd_main,
chroot_main,
chrt_main,
chvt_main,
cksum_main,
clear_main,
cmp_main,
comm_main,
cp_main,
cpio_main,
crond_main,
crontab_main,
cryptpw_main,
cut_main,
date_main,
dc_main,
dd_main,
deallocvt_main,
deluser_main,
deluser_main,
df_main,
dhcprelay_main,
diff_main,
dirname_main,
dmesg_main,
dnsd_main,
dos2unix_main,
du_main,
dumpkmap_main,
echo_main,
ed_main,
grep_main,
eject_main,
env_main,
ether_wake_main,
expand_main,
expr_main,
fakeidentd_main,
false_main,
fbset_main,
freeramdisk_main,
fdformat_main,
fdisk_main,
grep_main,
find_main,
fold_main,
free_main,
freeramdisk_main,
fsck_main,
ftpgetput_main,
ftpgetput_main,
fuser_main,
getopt_main,
getty_main,
grep_main,
gunzip_main,
gzip_main,
halt_main,
hdparm_main,
head_main,
hexdump_main,
hostid_main,
hostname_main,
hwclock_main,
id_main,
ifconfig_main,
ifupdown_main,
ifupdown_main,
inetd_main,
init_main,
install_main,
ipcalc_main,
ipcrm_main,
ipcs_main,
kill_main,
kill_main,
kill_main,
klogd_main,
last_main,
length_main,
less_main,
setarch_main,
setarch_main,
init_main,
ln_main,
loadfont_main,
loadkmap_main,
logger_main,
login_main,
logname_main,
logread_main,
ls_main,
md5_sha1_sum_main,
mesg_main,
microcom_main,
mkdir_main,
mkfifo_main,
mknod_main,
mkswap_main,
mktemp_main,
more_main,
mount_main,
mountpoint_main,
mv_main,
nameif_main,
nc_main,
netstat_main,
nice_main,
nmeter_main,
nohup_main,
nslookup_main,
od_main,
openvt_main,
passwd_main,
patch_main,
pidof_main,
ping_main,
ping6_main,
pivot_root_main,
pgrep_main,
halt_main,
printenv_main,
printf_main,
ps_main,
pscan_main,
pwd_main,
rdate_main,
readlink_main,
readprofile_main,
realpath_main,
halt_main,
renice_main,
reset_main,
resize_main,
rm_main,
rmdir_main,
route_main,
rpm_main,
rpm2cpio_main,
script_main,
sed_main,
seq_main,
setarch_main,
setconsole_main,
setkeycodes_main,
setsid_main,
ash_main,
md5_sha1_sum_main,
sleep_main,
sort_main,
split_main,
start_stop_daemon_main,
stat_main,
strings_main,
stty_main,
su_main,
sulogin_main,
sum_main,
swap_on_off_main,
swap_on_off_main,
switch_root_main,
sync_main,
sysctl_main,
syslogd_main,
tail_main,
tar_main,
tee_main,
telnet_main,
telnetd_main,
test_main,
tftp_main,
tftpd_main,
time_main,
top_main,
touch_main,
tr_main,
traceroute_main,
true_main,
tty_main,
udhcpc_main,
udhcpd_main,
tcpudpsvd_main,
umount_main,
uname_main,
uncompress_main,
expand_main,
uniq_main,
dos2unix_main,
unzip_main,
uptime_main,
usleep_main,
uudecode_main,
uuencode_main,
vconfig_main,
vi_main,
vlock_main,
watch_main,
watchdog_main,
wc_main,
wget_main,
which_main,
who_main,
whoami_main,
xargs_main,
yes_main,
gunzip_main,
zcip_main,
};
const uint16_t applet_nameofs[] ALIGN2 = {
0x0000,
0x0002,
0x0005,
0x000e,
0x0016,
0x001f,
0x0022,
0x0026,
0x002d,
0x0031,
0x0035,
0x003e,
0x0047,
0x004f,
0x0055,
0x005b,
0x005f,
0x0063,
0x0069,
0x006f,
0x0075,
0x007e,
0x0085,
0x008a,
0x008f,
0x0095,
0x009b,
0x009f,
0x00a4,
0x00a7,
0x00ac,
0x80b2,
0x00ba,
0x00c2,
0x00c6,
0x00cb,
0x00ce,
0x00d1,
0x00db,
0x00e4,
0x00ec,
0x00ef,
0x00f9,
0x00fe,
0x0106,
0x810c,
0x0111,
0x011a,
0x011d,
0x0126,
0x012b,
0x012e,
0x0134,
0x013a,
0x013e,
0x0149,
0x0150,
0x0155,
0x0160,
0x0166,
0x016c,
0x0174,
0x017d,
0x0183,
0x0189,
0x018e,
0x0193,
0x0198,
0x01a4,
0x01a9,
0x01b0,
0x01b7,
0x01bd,
0x01c4,
0x01ca,
0x01cf,
0x01d6,
0x01db,
0x01e0,
0x01e7,
0x01ec,
0x01f4,
0x01fb,
0x0204,
0x020c,
0x020f,
0x0218,
0x021f,
0x0224,
0x022a,
0x022f,
0x0237,
0x823e,
0x8244,
0x0249,
0x024e,
0x0256,
0x025f,
0x0265,
0x026a,
0x0271,
0x0276,
0x027e,
0x0286,
0x028e,
0x0291,
0x029a,
0x02a3,
0x82aa,
0x02b0,
0x02b8,
0x02c0,
0x02c3,
0x02ca,
0x02cf,
0x02d8,
0x02de,
0x02e5,
0x02eb,
0x02f2,
0x02f9,
0x42fe,
0x0304,
0x030f,
0x0312,
0x0319,
0x031c,
0x0324,
0x0329,
0x0330,
0x0336,
0x033f,
0x0342,
0x8349,
0x0350,
0x0356,
0x435c,
0x0361,
0x0367,
0x0372,
0x0378,
0x0381,
0x038a,
0x0391,
0x0394,
0x039a,
0x039e,
0x03a4,
0x03ad,
0x03b9,
0x03c2,
0x03c9,
0x03d0,
0x03d6,
0x03dd,
0x03e0,
0x03e6,
0x03ec,
0x03f0,
0x03f9,
0x0400,
0x0404,
0x0408,
0x0410,
0x041b,
0x0427,
0x042e,
0x0431,
0x0439,
0x043f,
0x0444,
0x044a,
0x045c,
0x0461,
0x0469,
0x846e,
0x0471,
0x0479,
0x047d,
0x0485,
0x048c,
0x0498,
0x049d,
0x04a4,
0x04ac,
0x04b1,
0x04b5,
0x04b9,
0x04c0,
0x04c8,
0x04cd,
0x04d2,
0x04d8,
0x04dd,
0x04e1,
0x04e7,
0x44ea,
0x04f5,
0x04fa,
0x04fe,
0x0505,
0x050c,
0x0513,
0x051a,
0x0520,
0x052b,
0x0534,
0x0539,
0x0542,
0x0548,
0x054f,
0x0556,
0x055f,
0x0568,
0x0570,
0x8573,
0x0579,
0x057f,
0x0588,
0x058b,
0x0590,
0x0596,
0x059a,
0x05a1,
0x05a7,
0x05ab,
0x05b0,
};
const uint8_t applet_install_loc[] ALIGN1 = {
0x33,
0x11,
0x32,
0x32,
0x31,
0x13,
0x33,
0x33,
0x11,
0x11,
0x44,
0x33,
0x33,
0x33,
0x11,
0x34,
0x33,
0x31,
0x31,
0x11,
0x41,
0x33,
0x41,
0x33,
0x11,
0x11,
0x33,
0x33,
0x43,
0x41,
0x31,
0x12,
0x33,
0x23,
0x32,
0x33,
0x21,
0x11,
0x21,
0x32,
0x33,
0x21,
0x23,
0x22,
0x24,
0x13,
0x33,
0x31,
0x23,
0x33,
0x13,
0x01,
0x41,
0x32,
0x31,
0x12,
0x33,
0x13,
0x13,
0x12,
0x11,
0x11,
0x32,
0x11,
0x33,
0x33,
0x33,
0x13,
0x11,
0x32,
0x12,
0x13,
0x13,
0x34,
0x34,
0x32,
0x33,
0x11,
0x12,
0x33,
0x31,
0x21,
0x33,
0x31,
0x31,
0x23,
0x31,
0x11,
0x32,
0x22,
0x12,
0x22,
0x13,
0x33,
0x34,
0x33,
0x33,
0x31,
0x13,
0x23,
0x34,
0x11,
0x31,
0x33,
0x33,
0x31,
0x23,
0x31,
0x21,
0x33,
0x33,
0x33,
0x13,
0x02,
};

#define MAX_APPLET_NAME_LEN 17
